==> nocc-1.9.5.txz: usr/local/www/nocc/lang/tr.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: tr.php 2602 2014-03-31 22:00:26Z siebrand $
 */
/** Turkish (Türkçe)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Emperyan
 * @author Joseph
 * @author Meelo
 * @author Vito Genovese
 * @author İsmail Özer <aceleyolla AT gmx DOT net>
 */

$lang_locale = 'tr_TR.UTF-8';
$default_date_format = '%d-%m-%Y';
$no_locale_date_format = '%d-%m-%Y';
$default_time_format = '%I:%M %p';
$err_user_empty = 'Kullanıcı kısmını boş geçemezsiniz';
$err_passwd_empty = 'Parola kısmını boş geçemezsiniz';
$alt_delete = 'Seçili iletileri sil';
$alt_delete_one = 'Seçili iletiyi sil';
$alt_new_msg = 'Yeni ileti';
$alt_reply = 'Yazana cevapla';
$alt_reply_all = 'Tümüne cevapla';
$alt_forward = 'Başkasına İlet';
$alt_next = 'İleri';
$alt_prev = 'Geri';
$title_next_page = 'Sonraki Sayfa';
$title_prev_page = 'Önceki Sayfa';
$title_next_msg = 'Sonraki İleti';
$title_prev_msg = 'Önceki İleti';
$html_theme_label = 'Biçim:';
$html_welcome = '%1$s\'e Hoş Geldiniz';
$html_login = 'Oturum aç';
$html_user_label = 'Kullanıcı:';
$html_passwd_label = 'Şifre:';
$html_submit = 'Giriş';
$html_help = 'Yardım';
$html_server_label = 'Sunucu:';
$html_wrong = 'Kullanıcı adı ya da parola hatalı';
$html_retry = 'Tekrar Deneyin';
$html_remember = 'Ayarları Hatırla';
$html_lang_label = 'Dil:';
$html_msgperpage_label = 'Sayfa başına mesaj sayısı:';
$html_preferences = 'Ayarlar';
$html_full_name_label = 'Tam isim:';
$html_email_address_label = 'E-posta Adresi:';
$html_bccself = 'Beni bcc listesine ekle';
$html_hide_addresses = 'Adresleri gizli tut';
$html_outlook_quoting = 'Outlook biçimi işaretle';
$html_reply_to = 'Cevapla';
$html_reply_to_label = 'Yanıtla:';
$html_use_signature = 'İmza kullan';
$html_signature = 'İmza';
$html_signature_label = 'İmza:';
$html_reply_leadin_label = 'Yanıt giriş:';
$html_prefs_updated = 'Ayarlar güncelleşti';
$html_manage_folders_link = 'IMAP dosyasını yönet';
$html_manage_filters_link = 'E-posta süzgecini yönet';
$html_use_graphical_smilies = 'Grafik ifadelere izin ver';
$html_sent_folder_label = 'Gönderilen iletileri ayrı klasöre kopyala:';
$html_trash_folder_label = 'Silinmiş e-postaları ayrı klasöre taşı:';
$html_colored_quotes = 'Renkli tırnak işareti kullan';
$html_display_struct = 'Biçimli yazıları göster';
$html_send_html_mail = 'İletiyi HTML formatında gönder';
$html_folders = 'Klasörler';
$html_folders_create_failed = 'Klasör oluşturmada bir hata çıktı!';
$html_folders_sub_failed = 'Klasörü paylaşmada hata oluştu!';
$html_folders_unsub_failed = 'Klasörün paylaşımı kaldırılamadı!';
$html_folders_rename_failed = 'Klasör farklı adlandırlamadı!';
$html_folders_updated = 'Klasörler güncelleştirildi';
$html_folder_subscribe = 'Klasörü paylaş';
$html_folder_rename = 'Farklı adlandır';
$html_folder_create = 'Yeni klasörü oluştur';
$html_folder_remove = 'Klasörü kapat';
$html_folder_delete = 'Klasörü sil';
$html_folder_to = 'Yeni adı';
$html_filter_remove = 'Sil';
$html_filter_body = 'İleti metni';
$html_filter_subject = 'İleti başlığı';
$html_filter_to = 'Kime (To)';
$html_filter_cc = 'Kopya (Cc)';
$html_filter_from = 'Gönderen';
$html_filter_change_tip = 'İleti süzgecini değiştirmek için varolanı düzenle.';
$html_reapply_filters = 'Tüm süzgeçleri yeniden çalıştır';
$html_filter_contains = 'Süzgecin içeriği';
$html_filter_name = 'Süzgeç adı';
$html_filter_action = 'Süzgecin işlevi';
$html_filter_moveto = 'Buraya taşı';
$html_select_one = '-- Seç --';
$html_and = 'Ve';
$html_new_msg_in = 'deki yeni iletiyi';
$html_or = 'Veya';
$html_move = 'Taşı';
$html_copy = 'Kopyala';
$html_messages_to = 'seçilen iletiyi buraya';
$html_gotopage = 'Sayfaya git';
$html_gotofolder = 'Klasöre git';
$html_other_folders = 'Klasör listesi';
$html_page = 'Sayfa';
$html_of = 'dan';
$html_view_header = 'Başlıkları Göster';
$html_remove_header = 'Başlıkları Gizle';
$html_inbox = 'Gelen Kutusu';
$html_new_msg = 'Yeni İleti';
$html_reply = 'Cevapla';
$html_reply_short = 'Yanıt:';
$html_reply_all = 'Tümüne cevapla';
$html_forward = 'İlet';
$html_forward_short = 'İlt:';
$html_forward_info = 'İletmek istenilen mesaj bu iletinin içinde ek olarak gönderilecektir.';
$html_delete = 'Sil';
$html_new = 'Yeni';
$html_mark = 'Sil';
$html_att_label = 'Ek:';
$html_atts_label = 'Ekler:';
$html_unknown = '[bilinmiyor]';
$html_part_x = 'Bölüm %s';
$html_attach = 'Ekle';
$html_attach_forget = 'İletiyi göndermeden önce dosyayı eklemelisiniz !';
$html_attach_delete = 'İşaretleneni Sil';
$html_attach_none = 'İleti eki için bir dosya seçmelisiniz!';
$html_sort_by = 'Göre sırala';
$html_sort = 'Sırala';
$html_from = 'Gönderen';
$html_from_label = 'Gönderen:';
$html_subject = 'Konu';
$html_subject_label = 'Konu:';
$html_date = 'Tarih';
$html_date_label = 'Tarih:';
$html_sent_label = 'Gönder:';
$html_wrote = 'Yazdı';
$html_size = 'Boyut';
$html_totalsize = 'Toplam Boyut';
$html_kb = ' KB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'Bayt';
$html_filename = 'Dosya Adı';
$html_to = 'Alıcı';
$html_to_label = 'Alıcı:';
$html_cc = 'Kopya (Cc)';
$html_cc_label = 'Cc:';
$html_bcc_label = 'Bcc:';
$html_nosubject = 'Konusuz';
$html_send = 'Gönder';
$html_cancel = 'İptal';
$html_no_mail = 'İleti Yok.';
$html_logout = 'Çıkış';
$html_msg = 'İleti';
$html_msgs = 'İletiler';
$html_configuration = 'Bu sunucu henüz ayarlanmamış!';
$html_priority = 'Öncelik';
$html_priority_label = 'Öncelik:';
$html_lowest = 'En düşük';
$html_low = 'Düşük';
$html_normal = 'Orta';
$html_high = 'Yüksek';
$html_highest = 'En yüksek';
$html_flagged = 'İşaretli';
$html_spam = 'Yığın mesaj (spam)';
$html_spam_warning = 'Bu mesaj yığın mesajı (spam) olarak sınıflandırılmıştır.';
$html_receipt = 'İleti okundu onayı gönderilsin';
$html_select = 'Seç';
$html_select_all = 'Ters seçim yap';
$html_select_contacts = 'Kişileri seç';
$html_loading_image = 'Resim yükle';
$html_send_confirmed = 'İletiniz başarı ile gönderildi';
$html_no_sendaction = 'Bir aksiyon şey seçilmedi. JavaScriptini seçin ve tekrar deneyin.';
$html_error_occurred = 'Bir teknik hatası oluştu';
$html_prefs_file_error = 'Hata: Ayarlar dosyası yazmak için açılamadı.';
$html_wrap = 'Giden mesajlar için sözcük kaydırma karakter sayısı:';
$html_wrap_none = 'Sözcük kaydırma yok';
$html_usenet_separator = 'İmzanın önüne Usenet ayırıcısı ekle ("-- \n")';
$html_mark_as = 'Olarak seç:';
$html_read = 'Okundu';
$html_unread = 'Okunmadı';
$html_encoding_label = 'Karakter kodlama:';
$html_add = 'Ekle';
$html_contacts = '%1$s Kişi';
$html_modify = 'Değiştir';
$html_back = 'Geri';
$html_contact_add = 'Yeni kişi ekle';
$html_contact_mod = 'Kişi bilgilerini düzenle';
$html_contact_first = 'İsim';
$html_contact_last = 'Soyadı';
$html_contact_nick = 'Rumuz';
$html_contact_mail = 'E-posta';
$html_contact_list = '%1$s\'in kişi listesi';
$html_contact_del = 'Kişi listesinden';
$html_contact_count = '%1$d Kişi';
$html_contact_err1 = 'En fazla kişi sayısı "%1$d"';
$html_contact_err2 = 'Yeni kişi ekleyemezsiniz';
$html_contact_err3 = 'Kişiler listesini düzenleme hakkınız yoktur';
$html_contact_none = 'Herhangi bir kişi bulunamadı.';
$html_del_msg = 'Seçilen iletiler gerçekten silinsin mi?';
$html_down_mail = 'İndir';
$original_msg = '-- Özgün İleti --';
$to_empty = ' \'Alıcı\' alanı boş geçilemez !';
$html_images_warning = 'Güvenliğiniz için bazı resimlerin gösterimi engellenmiştir.';
$html_images_display = 'Resimleri göster';
$html_smtp_error_no_conn = 'SMTP sunucusuna erişmede hata oluştu.';
$html_smtp_error_unexpected = 'Geçersiz SMTP cevabı geldi:';
$lang_could_not_connect = 'Sunucuya bağlanmada bir hata oluştu';
$lang_invalid_msg_num = 'Yanlış haber numarası';
$html_file_upload_attack = 'Yüklenen dosya bulunamadı';
$html_invalid_email_address = 'Geçersiz E-posta adresi';
$html_invalid_msg_per_page = 'Sayfa başı yanlış ileti sayısı';
$html_invalid_wrap_msg = 'İletinin satır başlığı doğru değil';
$html_seperate_msg_win = 'İletiyi yeni bir pencerede göster';
$html_err_file_contacts = 'Kişiler list dosyası bulunamadı.';
$html_session_file_error = 'Oturum bilgilerini yazma dosyası bulunamadı.';
$html_login_not_allowed = 'Bu kullanıcının girişi engellenmiştir.';
$lang_err_send_delay = 'İki e-posta arasında beklemeniz gerekir (%1$d saniye)';
$html_search = 'Ara';
$html_fd_filename = '%1$s indi';
$html_fd_filesize = '%1$d boyutunda';

==> nocc-1.9.6.txz: usr/local/www/nocc/lang/tr.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: tr.php 2656 2015-09-10 08:37:08Z siebrand $
 */
/** Turkish (Türkçe)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Emperyan
 * @author Joseph
 * @author McAang
 * @author Meelo
 * @author Uğurkent
 * @author Vito Genovese
 * @author İsmail Özer <aceleyolla AT gmx DOT net>
 */

$lang_locale = 'tr_TR.UTF-8';
$default_date_format = '%d-%m-%Y';
$no_locale_date_format = '%d-%m-%Y';
$default_time_format = '%I:%M %p';
$err_user_empty = 'Kullanıcı kısmını boş geçemezsiniz';
$err_passwd_empty = 'Parola kısmını boş geçemezsiniz';
$alt_delete = 'Seçili iletileri sil';
$alt_delete_one = 'Seçili iletiyi sil';
$alt_new_msg = 'Yeni ileti';
$alt_reply = 'Yazana cevapla';
$alt_reply_all = 'Tümüne cevapla';
$alt_forward = 'Başkasına İlet';
$alt_next = 'İleri';
$alt_prev = 'Geri';
$title_next_page = 'Sonraki Sayfa';
$title_prev_page = 'Önceki Sayfa';
$title_next_msg = 'Sonraki İleti';
$title_prev_msg = 'Önceki İleti';
$html_theme_label = 'Biçim:';
$html_welcome = '%1$s\'e Hoş Geldiniz';
$html_login = 'Oturum aç';
$html_user_label = 'Kullanıcı:';
$html_passwd_label = 'Şifre:';
$html_submit = 'Giriş';
$html_help = 'Yardım';
$html_server_label = 'Sunucu:';
$html_wrong = 'Kullanıcı adı ya da parola hatalı';
$html_retry = 'Tekrar Deneyin';
$html_remember = 'Ayarları Hatırla';
$html_lang_label = 'Dil:';
$html_msgperpage_label = 'Sayfa başına mesaj sayısı:';
$html_preferences = 'Ayarlar';
$html_full_name_label = 'Tam isim:';
$html_email_address_label = 'E-posta Adresi:';
$html_bccself = 'Beni bcc listesine ekle';
$html_hide_addresses = 'Adresleri gizli tut';
$html_outlook_quoting = 'Outlook biçimi işaretle';
$html_reply_to = 'Cevapla';
$html_reply_to_label = 'Yanıtla:';
$html_use_signature = 'İmza kullan';
$html_signature = 'İmza';
$html_signature_label = 'İmza:';
$html_reply_leadin_label = 'Yanıt giriş:';
$html_prefs_updated = 'Ayarlar güncelleşti';
$html_manage_folders_link = 'IMAP dosyasını yönet';
$html_manage_filters_link = 'E-posta süzgecini yönet';
$html_use_graphical_smilies = 'Grafik ifadelere izin ver';
$html_sent_folder_label = 'Gönderilen iletileri ayrı klasöre kopyala:';
$html_trash_folder_label = 'Silinmiş e-postaları ayrı klasöre taşı:';
$html_colored_quotes = 'Renkli tırnak işareti kullan';
$html_display_struct = 'Biçimli yazıları göster';
$html_send_html_mail = 'İletiyi HTML formatında gönder';
$html_folders = 'Klasörler';
$html_folders_create_failed = 'Klasör oluşturmada bir hata çıktı!';
$html_folders_sub_failed = 'Klasörü paylaşmada hata oluştu!';
$html_folders_unsub_failed = 'Klasörün paylaşımı kaldırılamadı!';
$html_folders_rename_failed = 'Klasör farklı adlandırlamadı!';
$html_folders_updated = 'Klasörler güncelleştirildi';
$html_folder_subscribe = 'Klasörü paylaş';
$html_folder_rename = 'Farklı adlandır';
$html_folder_create = 'Yeni klasörü oluştur';
$html_folder_remove = 'Klasörü kapat';
$html_folder_delete = 'Klasörü sil';
$html_folder_to = 'Yeni adı';
$html_filter_remove = 'Sil';
$html_filter_body = 'İleti metni';
$html_filter_subject = 'İleti başlığı';
$html_filter_to = 'Kime (To)';
$html_filter_cc = 'Kopya (Cc)';
$html_filter_from = 'Gönderen';
$html_filter_change_tip = 'İleti süzgecini değiştirmek için varolanı düzenle.';
$html_reapply_filters = 'Tüm süzgeçleri yeniden çalıştır';
$html_filter_contains = 'Süzgecin içeriği';
$html_filter_name = 'Süzgeç adı';
$html_filter_action = 'Süzgecin işlevi';
$html_filter_moveto = 'Buraya taşı';
$html_select_one = '-- Seç --';
$html_and = 'Ve';
$html_new_msg_in = 'deki yeni iletiyi';
$html_or = 'Veya';
$html_move = 'Taşı';
$html_copy = 'Kopyala';
$html_messages_to = 'seçilen iletiyi buraya';
$html_gotopage = 'Sayfaya Git';
$html_gotofolder = 'Klasöre git';
$html_other_folders = 'Klasör listesi';
$html_page = 'Sayfa';
$html_of = 'dan';
$html_view_header = 'Başlıkları Göster';
$html_remove_header = 'Başlıkları Gizle';
$html_inbox = 'Gelen Kutusu';
$html_new_msg = 'Yeni İleti';
$html_reply = 'Cevapla';
$html_reply_short = 'Yanıt:';
$html_reply_all = 'Tümüne cevapla';
$html_forward = 'İlet';
$html_forward_short = 'İlt:';
$html_forward_info = 'İletmek istenilen mesaj bu iletinin içinde ek olarak gönderilecektir.';
$html_delete = 'Sil';
$html_new = 'Yeni';
$html_mark = 'Sil';
$html_att_label = 'Ek:';
$html_atts_label = 'Ekler:';
$html_unknown = '[bilinmiyor]';
$html_part_x = 'Bölüm %s';
$html_attach = 'Ekle';
$html_attach_forget = 'İletiyi göndermeden önce dosyayı eklemelisiniz !';
$html_attach_delete = 'İşaretleneni Sil';
$html_attach_none = 'İleti eki için bir dosya seçmelisiniz!';
$html_sort_by = 'Göre sırala';
$html_sort = 'Sırala';
$html_from = 'Gönderen';
$html_from_label = 'Gönderen:';
$html_subject = 'Konu';
$html_subject_label = 'Konu:';
$html_date = 'Tarih';
$html_date_label = 'Tarih:';
$html_sent_label = 'Gönder:';
$html_wrote = 'Yazdı';
$html_size = 'Boyut';
$html_totalsize = 'Toplam Boyut';
$html_kb = ' KB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'Bayt';
$html_filename = 'Dosya Adı';
$html_to = 'Alıcı';
$html_to_label = 'Alıcı:';
$html_cc = 'Kopya (Cc)';
$html_cc_label = 'Cc:';
$html_bcc_label = 'Bcc:';
$html_nosubject = 'Konusuz';
$html_send = 'Gönder';
$html_cancel = 'İptal';
$html_no_mail = 'İleti Yok.';
$html_logout = 'Çıkış';
$html_msg = 'İleti';
$html_msgs = 'İletiler';
$html_configuration = 'Bu sunucu henüz ayarlanmamış!';
$html_priority = 'Öncelik';
$html_priority_label = 'Öncelik:';
$html_lowest = 'En düşük';
$html_low = 'Düşük';
$html_normal = 'Orta';
$html_high = 'Yüksek';
$html_highest = 'En yüksek';
$html_flagged = 'İşaretli';
$html_spam = 'Yığın mesaj (spam)';
$html_spam_warning = 'Bu mesaj yığın mesajı (spam) olarak sınıflandırılmıştır.';
$html_receipt = 'İleti okundu onayı gönderilsin';
$html_select = 'Seç';
$html_select_all = 'Ters seçim yap';
$html_select_contacts = 'Kişileri seç';
$html_loading_image = 'Resim yükle';
$html_send_confirmed = 'İletiniz başarı ile gönderildi';
$html_no_sendaction = 'Bir aksiyon şey seçilmedi. JavaScriptini seçin ve tekrar deneyin.';
$html_error_occurred = 'Bir teknik hatası oluştu';
$html_prefs_file_error = 'Hata: Ayarlar dosyası yazmak için açılamadı.';
$html_wrap = 'Giden mesajlar için sözcük kaydırma karakter sayısı:';
$html_wrap_none = 'Sözcük kaydırma yok';
$html_usenet_separator = 'İmzanın önüne Usenet ayırıcısı ekle ("-- \n")';
$html_mark_as = 'Olarak seç:';
$html_read = 'Okundu';
$html_unread = 'Okunmadı';
$html_encoding_label = 'Karakter kodlama:';
$html_add = 'Ekle';
$html_contacts = '%1$s Kişi';
$html_modify = 'Değiştir';
$html_back = 'Geri';
$html_contact_add = 'Yeni kişi ekle';
$html_contact_mod = 'Kişi bilgilerini düzenle';
$html_contact_first = 'İsim';
$html_contact_last = 'Soyadı';
$html_contact_nick = 'Rumuz';
$html_contact_mail = 'E-posta';
$html_contact_list = '%1$s\'in kişi listesi';
$html_contact_del = 'Kişi listesinden';
$html_contact_count = '%1$d Kişi';
$html_contact_err1 = 'En fazla kişi sayısı "%1$d"';
$html_contact_err2 = 'Yeni kişi ekleyemezsiniz';
$html_contact_err3 = 'Kişiler listesini düzenleme hakkınız yoktur';
$html_contact_none = 'Herhangi bir kişi bulunamadı.';
$html_contact_all = 'Hepsini göster';
$html_del_msg = 'Seçilen iletiler gerçekten silinsin mi?';
$html_down_mail = 'İndir';
$original_msg = '-- Özgün İleti --';
$to_empty = ' \'Alıcı\' alanı boş geçilemez !';
$html_images_warning = 'Güvenliğiniz için bazı resimlerin gösterimi engellenmiştir.';
$html_images_display = 'Resimleri göster';
$html_smtp_error_no_conn = 'SMTP sunucusuna erişmede hata oluştu.';
$html_smtp_error_unexpected = 'Geçersiz SMTP cevabı geldi:';
$lang_could_not_connect = 'Sunucuya bağlanmada bir hata oluştu';
$lang_invalid_msg_num = 'Yanlış haber numarası';
$html_file_upload_attack = 'Yüklenen dosya bulunamadı';
$html_invalid_email_address = 'Geçersiz E-posta adresi';
$html_invalid_msg_per_page = 'Sayfa başı yanlış ileti sayısı';
$html_invalid_wrap_msg = 'İletinin satır başlığı doğru değil';
$html_seperate_msg_win = 'İletiyi yeni bir pencerede göster';
$html_err_file_contacts = 'Kişiler list dosyası bulunamadı.';
$html_session_file_error = 'Oturum bilgilerini yazma dosyası bulunamadı.';
$html_login_not_allowed = 'Bu kullanıcının girişi engellenmiştir.';
$lang_err_send_delay = 'İki e-posta arasında beklemeniz gerekir (%1$d saniye)';
$html_search = 'Ara';
$html_fd_filename = '%1$s indi';
$html_fd_filesize = '%1$d boyutunda';
